@@ -13,7 +13,7 @@ from urllib.parse import urlparse, parse_qs
 from .app.configs_controller import ConfigsController
 from .app.proxy_controller import ProxyController
 from .app.statuses_controller import StatusesController
-from .lib import headers
+from .lib.constants import headers
 
 class SimpleHTTPRequestHandler(BaseHTTPRequestHandler):
     ROOT_DIR = os.path.dirname(os.path.realpath(__file__))
@@ -228,6 +228,9 @@ class SimpleHTTPRequestHandler(BaseHTTPRequestHandler):
             ['/'.join([PROXY_PATH, 'get']), ProxyController.instance().do_GET],
             [STATUS_PATH, StatusesController.instance().get_status],
         ],
+        'POST': [
+            ['/'.join([PROXY_PATH, 'post']), ProxyController.instance().do_POST],
+        ],
         'PUT': [
             [CONFIGS_PATH, ConfigsController.instance().put_configs],
             ['/'.join([PROXY_PATH, 'put']), ProxyController.instance().do_PUT],
